#
# spec file for package qmmp
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_with ffmpeg
%bcond_with mad
%bcond_with faad

%define soname 0

Name:           qmmp
Version:        0.7.0
Release:        44.1
Summary:        XMMS-like audio player
License:        GPL-2.0+
Group:          Productivity/Multimedia/Sound/Players
Url:            http://qmmp.ylsoftware.com/
Source0:        http://qmmp.googlecode.com/files/qmmp-%{version}.tar.bz2
# PATCH-FEATURE-OPENSUSE qmmp-0.6.1-default_pulse.patch reddwarf@opensuse.org -- Use PulseAudio instead of ALSA by default
Patch0:         qmmp-0.6.1-default_pulse.patch
# PATCH-FIX-UPSTREAM qmmp-fix_cdda_version.patch pascal.bleser@opensuse.org -- Fix header detection for cdparanoia cdda.h
Patch1:         qmmp-fix_cdda_version.patch
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libmpcdec-devel
BuildRequires:  pkgconfig(QtCore)
BuildRequires:  pkgconfig(QtDBus)
BuildRequires:  pkgconfig(QtGui)
BuildRequires:  pkgconfig(QtNetwork)
BuildRequires:  pkgconfig(QtOpenGL)
BuildRequires:  pkgconfig(QtXml)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(enca) >= 1.9
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(opus)
# Standard Jack version is not new enough until openSUSE 12.1
%if 0%{?suse_version} > 1140
BuildRequires:  pkgconfig(jack)
%endif
BuildRequires:  pkgconfig(libbs2b)
BuildRequires:  pkgconfig(libcddb)
BuildRequires:  pkgconfig(libcdio)
BuildRequires:  pkgconfig(libcdio_cdda)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libgme)
BuildRequires:  pkgconfig(libmms)
BuildRequires:  pkgconfig(libmodplug)
BuildRequires:  pkgconfig(libprojectM)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libpulse-simple)
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(taglib)
BuildRequires:  pkgconfig(vorbisfile)
BuildRequires:  pkgconfig(wavpack)
%if %{with ffmpeg}
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
%endif
%if %{with mad}
BuildRequires:  pkgconfig(mad)
%endif
%if %{with faad}
BuildRequires:  libfaad-devel
%endif
Requires:       qmmp(%{soname})(Input)
Requires:       qmmp(%{soname})(Output)
Requires:       qmmp(%{soname})(Ui)

%description
This program is an audio-player, written with help of Qt library. The program
has user interface, similar winamp or xmms.

%package -n libqmmp%{soname}
Summary:        Qmmp library
Group:          System/Libraries
Suggests:       libqmmp%{soname}-plugin-mplayer
Recommends:     libqmmp%{soname}-plugins

%description -n libqmmp%{soname}
Qmmp library.

%package -n libqmmp%{soname}-plugins
Summary:        Plugins for libqmmp
Group:          System/Libraries
Provides:       qmmp(%{soname})(Input)
Provides:       qmmp(%{soname})(Output)
Provides:       qmmp(%{soname})(Ui)

%description -n libqmmp%{soname}-plugins
Plugins for libqmmp.

%package -n libqmmp%{soname}-plugin-mplayer
Summary:        MPlayer plugin for libqmmp
Group:          System/Libraries
Requires:       %{_bindir}/mplayer

%description -n libqmmp%{soname}-plugin-mplayer
MPlayer plugin for libqmmp.

%package -n libqmmp-devel
Summary:        Development files for libqmmp
Group:          Development/Libraries/C and C++
Requires:       libqmmp%{soname} = %{version}

%description -n libqmmp-devel
Development files for libqmmp.

%prep
%setup -q
%patch0
%patch1

%build
mkdir build
cd build
export CFLAGS='%{optflags}'
export CXXFLAGS='%{optflags}'
cmake -DCMAKE_BUILD_WITH_INSTALL_RPATH=1 \
      -DCMAKE_INSTALL_PREFIX=%{_prefix} \
      -DLIB_DIR=%{_lib} \
      -DCMAKE_BUILD_TYPE=Release \
      -DCMAKE_VERBOSE_MAKEFILE=TRUE \
      -DUSE_HAL=FALSE \
      -DUSE_OSS=FALSE \
      -DUSE_OSS4=FALSE \
      ..
make %{?_smp_mflags}

%install
cd build
%make_install

%post
%icon_theme_cache_post
%desktop_database_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%post -n libqmmp%{soname} -p /sbin/ldconfig

%postun -n libqmmp%{soname} -p /sbin/ldconfig

%post -n libqmmp%{soname}-plugins
%desktop_database_post

%postun -n libqmmp%{soname}-plugins
%desktop_database_postun

%files
%defattr(0644,root,root,0755)
%doc AUTHORS ChangeLog COPYING README
%attr(0755,root,root) %{_bindir}/qmmp
%{_datadir}/qmmp
%{_datadir}/applications/qmmp.desktop
%{_datadir}/applications/qmmp_enqueue.desktop
%{_datadir}/applications/qmmp_dir.desktop
%{_datadir}/icons/hicolor/*/apps/qmmp*

%files -n libqmmp%{soname}
%defattr(0644,root,root,0755)
%{_libdir}/libqmmp.so.%{soname}*
%{_libdir}/libqmmpui.so.%{soname}*

%files -n libqmmp%{soname}-plugins
%defattr(0644,root,root,0755)
%{_libdir}/qmmp
%exclude %{_libdir}/qmmp/Engines/libmplayer.so
%{_datadir}/applications/qmmp_cue.desktop

%files -n libqmmp%{soname}-plugin-mplayer
%defattr(0644,root,root,0755)
%{_libdir}/qmmp/Engines/libmplayer.so

%files -n libqmmp-devel
%defattr(0644,root,root,0755)
%{_includedir}/qmmp
%{_includedir}/qmmpui
%{_libdir}/libqmmp.so
%{_libdir}/libqmmpui.so
%{_libdir}/pkgconfig/qmmp.pc
%{_libdir}/pkgconfig/qmmpui.pc

%changelog
* Wed May 15 2013 mhrusecky@suse.com
- Only suggesting instead of recomending mplayer plugin as mplayer is not in
  factory yet
* Mon Apr 15 2013 pascal.bleser@opensuse.org
- update to 0.7.0:
  * added udisks2 plugin
  * added opus plugin
  * added track change plugin
  * added tracks copy/paste plugin
  * added x-content/audio-cdda content type
  * added 24/32-bit equalizer
  * added unity integration
  * added user interface language option
  * added playlists auto-save feature
  * added unified URL dialog
  * added playlists downloading support to the command line parser
  * added volume control support to the waveout plugin
  * added wildmidi configuration file auto-search
  * added sorting by file creation date
  * added automatic 16-bit audio converter
  * added pause handling to the scrobbler plugin
  * enabled UTF-8 by default for cue files and shoutcast metadata
  * enabled more formats by default in the ffmpeg plugin
  * improved analyzer plugin (variable size, fullscreen mode, etc)
  * improved last.fm registration
  * improved configuration dialog
  * removed QtXML dependence from the scrobbler plugin
  * disabled udisks plugin by default
* Thu Mar 28 2013 reddwarf@opensuse.org
- Update to 0.6.8
  * fixed bugs in the mpris plugin
  * fixed segmentation fault when running without output plugins
  * updated Japanese translation (Ryota Shimamo)
* Thu Feb 21 2013 reddwarf@opensuse.org
- Update to 0.6.7
  * added lubuntu integration
  * improved rtl locales support
  * fixed latest paranoia support
  * fixed libav 0.8.x support
  * fixed 'enter' hotkey in the playlist browser
  * fixed 24-bit mode support in the src plugin
  * fixed compiler warnings
* Fri Jan 11 2013 reddwarf@opensuse.org
- Update to 0.6.6
  * added support for http redirect to the url dialog
  * added ffmpeg 1.1 support
  * fixed 24/32-bit mode support in the src plugin
  * fixed seeking when using oss4 as output
  * fixed streaming support in the ffmpeg plugin
  * fixed build without qt3support headers (thanks to Dmitry Smolin)
  * fixed playlist titlebar cursor
  * fixed mpris2 support
  * fixed typos
  * updated Hebrew translation (Genghis Khan)
- Disable OSS/OSS4 output support
* Sun Dec  9 2012 reddwarf@opensuse.org
- Update to 0.6.5
  * added latest psi/psi+ support
  * added Hebrew translation (Genghis Khan)
  * increased default mms/http buffer size
  * fixed shortcut dialogs
  * fixed segmentation fault caused by http transport
  * fixed file type determination by content
  * fixed division line position in the playlist
  * fixed some bugs in the WaveOut plugin
  * updated Japanese translation (Ryota Shimamoto)
  * updated Russian translation
  * updated flac mime-type (Christian Morales Vega)
- Drop qmmp-0.6.4-flac_mimetype.patch. Applied upstream.
* Thu Dec  6 2012 reddwarf@opensuse.org
- Add qmmp-0.6.4-flac_mimetype.patch to use the correct MIME type
  to report support for FLAC files
* Sun Nov  4 2012 reddwarf@opensuse.org
- Update to 0.6.4
  * using UTF-8 encoding for shoutcast metadata by default
  * fixed visualization menu update after changing settings
  * fixed skinned user interface settings
  * fixed analyzer falloff speeds
  * fixed skinned user interface visualization switching
  * fixed playlist titlebar resize bug
  * fixed color selection widget
  * fixed possible crash in the transport plugins
  * fixed Russian translation
  * updated Japanese translation (Ryota Shimamoto)
* Wed Aug 22 2012 reddwarf@opensuse.org
- Update to 0.6.3
  * fixed typo in the about dialog
  * fixed FSF address
  * fixed cmake scripts
  * fixed filters of the directory scanner
  * fixed crash in the playlist popup message
  * updated Lithuanian translation (Algirdas Butkus)
- Removed qmmp-0.5.5-libcdio_mess.patch, fixed upstream
* Sat Aug  4 2012 reddwarf@opensuse.org
- Make qmmp require at least an input, output and ui plugin
* Mon Jul 30 2012 reddwarf@opensuse.org
- Update to 0.6.2
  * fixed crash in the http plugin
  * fixed possible crash in the cue parser
* Mon Jul 23 2012 reddwarf@opensuse.org
- Update to 0.6.1
  * added icons to the file dialog buttons
  * fixed icecast streams titles
  * fixed build
  * fixed default output under windows
  * fixed api documentation
  * fixed possible segmentation fault in the cue plugin
  * fixed cue parsing
  * fixed automatic charset detection
  * fixed Ukrainian translation (Gennadi Motsyo)
  * fixed Russian translation
* Sat Jun 30 2012 reddwarf@opensuse.org
- Update to 0.6.0
  * added converter plugin
  * added stream browser plugin
  * added file type determination by content (experimental)
  * added '--quit' command line option
  * added text scroller background option
  * added playlists separator option
  * added multiband equalizer api
  * added equalizer presets from Amarok (Thanks to Panagiotis Papadopoulos)
  * added playlits access from command line
  * added dithering to MPEG plugin
  * added priority support to decoder api
  * added user interface api
  * added default destination and file name pattern to fileops plugin
  * added additional directory filters
  * added feature to add files from command line to specific playlist
  * added pkg-config support
  * added vqf support
  * added feature to display shoutcast stream information
  * added 'jump to track' and 'forward/rewind' global hotkeys
  * added 'New Playlist' button
  * added sorting by disc number (Brice Videau)
  * added feature to use clipboard content in the URL dialog (Panagiotis Papadopoulos)
  * added scrobbler cache synchronization after successful submission (Ferdinand Vesely)
  * changed playlist insertion behavior
  * disabled OSS3 plugin by default
  * improved cue plugin
  * moved skinned ui to separate plugin
  * fixed 'hide on close' feature
  * fixed moc warnings during compilation
  * fixed IPC under windows
  * fixed windows-specific bugs
  * fixed problems with some asynchronous calls
  * fixed qmmp_cue.desktop
  * fixed saving playlists on logout
  * updated about dialog
  * updated Russian translation
  * updated Ukrainian translation (Gennadi Motsyo)
  * updated Japanese translation (Ryota Shimamoto)
  * updated Polish translation (Grzegorz Gibas)
  * updated German translation (Panagiotis Papadopoulos)
  * updated Dutch translation (Ronald Uitermark)
* Thu May 31 2012 reddwarf@opensuse.org
- Disable HAL plugin build
- Disable OSS plugin build
- Use PulseAudio by default instead of ALSA
* Sun May 27 2012 reddwarf@opensuse.org
- Fix build with ffmpeg 0.11
* Sat May 26 2012 reddwarf@opensuse.org
- Update to 0.5.5
  * added latest libcdio support
  * fixed Russian translation
  * fixed acc streams support
  * fixed aac bitrate calculation
  * fixed scrobbler failure when using Qt 4.8
  * fixed some cuesheets parsing
  * fixed --pause command line option behavior
  * updated Japanese translation
- Add missing %%desktop_database_post and %%icon_theme_cache_post
  scripts
- Remove obsoleted %%suse_update_desktop_file calls
- Add qmmp-0.5.5-libcdio_mess.patch to fix build with git version
  of libcdio
* Mon Sep  6 2010 reddwarf@opensuse.org
- New package. Version 0.4.2
